"""Console script for my-pkg."""

import sys
import click


@click.command()
def my_pkg(args=None):
    """Console script for my-pkg."""
    # fmt: off
    click.echo("Replace this message by putting your code into "
               "my_pkg.cli.main")
    click.echo("See click documentation at https://click.palletsprojects.com/")
    # fmt: on
    return 0


if __name__ == "__main__":
    sys.exit(my_pkg)  # pragma: no cover



from setuptools import setup
import versioneer

with open("requirements.txt") as f:
    requirements = f.read().splitlines()

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="my_pkg_478",
    version=versioneer.get_version(),
    description="My package",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Curtis Hampton",
    author_email="CurtLHampton@gmail.com",
    url="https://github.com/CurtLH/my_pkg",
    packages=["my_pkg"],
    install_requires=requirements,
    entry_points={"console_scripts": ["my_pkg=my_pkg.cli:my_pkg"]},
    extras_require={"dev": ["pytest", "sphinx"]},
    keywords="my_pkg",
    classifiers=["Programming Language :: Python :: 3.6", "Programming Language :: Python :: 3.7"],
)



def add(x, y):
    """Add two numbers together.

    Parameters
    ----------
    x : int
        The first number.
    y : int
        The second number.

    Returns
    -------
    z : int
        The first number plus the second number

    Example
    -------
    >>> add(2, 2)
    """
    return x + y


def subtract(x, y):
    """Subtract one number from another.

    Parameters
    ----------
    x : int
        The first number.
    y : int
        The second number.

    Returns
    -------
    z : int
        The first number minus the second number

    Example
    -------
    >>> subtract(2, 1)
    """
    return x - y
